<?php
$TRANSLATIONS = array(
"Sunday" => "nedelja",
"Monday" => "ponedeljak",
"Tuesday" => "utorak",
"Wednesday" => "srijeda",
"Thursday" => "četvrtak",
"Friday" => "petak",
"Saturday" => "subota",
"January" => "Siječanj",
"February" => "Veljača",
"March" => "Ožujak",
"April" => "Travanj",
"May" => "Svibanj",
"June" => "Lipanj",
"July" => "Srpanj",
"August" => "Kolovoz",
"September" => "Rujan",
"October" => "Listopad",
"November" => "Studeni",
"December" => "Prosinac",
"Settings" => "Postavke",
"Folder" => "mapa",
"Saving..." => "Spremanje...",
"seconds ago" => "sekundi prije",
"_%n minute ago_::_%n minutes ago_" => array("","",""),
"_%n hour ago_::_%n hours ago_" => array("","",""),
"today" => "danas",
"yesterday" => "jučer",
"_%n day ago_::_%n days ago_" => array("","",""),
"last month" => "prošli mjesec",
"_%n month ago_::_%n months ago_" => array("","",""),
"last year" => "prošlu godinu",
"years ago" => "godina",
"Reset password" => "Poništavanje lozinke",
"Yes" => "Da",
"No" => "Ne",
"Choose" => "Izaberi",
"Ok" => "U redu",
"_{count} file conflict_::_{count} file conflicts_" => array("","",""),
"Cancel" => "Odustani",
"Share" => "Podijeli",
"Error" => "Greška",
"Error while sharing" => "Greška prilikom djeljenja",
"Error while unsharing" => "Greška prilikom isključivanja djeljenja",
"Error while changing permissions" => "Greška prilikom promjena prava",
"Password protect" => "Zaštiti lozinkom",
"Set expiration date" => "Postavi datum isteka",
"Expiration date" => "Datum isteka",
"Share via email:" => "Dijeli preko email-a:",
"No people found" => "Osobe nisu pronađene",
"Resharing is not allowed" => "Ponovo dijeljenje nije dopušteno",
"Unshare" => "Makni djeljenje",
"can edit" => "može mjenjat",
"access control" => "kontrola pristupa",
"create" => "kreiraj",
"update" => "ažuriraj",
"delete" => "izbriši",
"Password protected" => "Zaštita lozinkom",
"Error unsetting expiration date" => "Greška prilikom brisanja datuma isteka",
"Error setting expiration date" => "Greška prilikom postavljanja datuma isteka",
"Delete" => "Obriši",
"Add" => "Dodaj",
"Use the following link to reset your password: {link}" => "Koristite ovaj link da biste poništili lozinku: {link}",
"You will receive a link to reset your password via Email." => "Primit ćete link kako biste poništili zaporku putem e-maila.",
"Username" => "Korisničko ime",
"New password" => "Nova lozinka",
"Personal" => "Osobno",
"Users" => "Korisnici",
"Apps" => "Aplikacije",
"Admin" => "Administrator",
"Help" => "Pomoć",
"Access forbidden" => "Pristup zabranjen",
"Cloud not found" => "Cloud nije pronađen",
"Create an <strong>admin account</strong>" => "Stvori <strong>administratorski račun</strong>",
"Password" => "Lozinka",
"Data folder" => "Mapa baze podataka",
"Configure the database" => "Konfiguriraj bazu podataka",
"Database user" => "Korisnik baze podataka",
"Database password" => "Lozinka baze podataka",
"Database name" => "Ime baze podataka",
"Database tablespace" => "Database tablespace",
"Database host" => "Poslužitelj baze podataka",
"Finish setup" => "Završi postavljanje",
"Log out" => "Odjava",
"remember" => "zapamtiti",
"Log in" => "Prijava"
);
$PLURAL_FORMS = "nplurals=3; plural=n%10==1 && n%100!=11 ? 0 : n%10>=2 && n%10<=4 && (n%100<10 || n%100>=20) ? 1 : 2;";
